@@ -4,12 +4,12 @@
 #' @description Given a dataset this function returns a (response) pattern frequencies table representation of it.
 #' @details No further details
 #' 
-#' @param x an object of class "matrix" or "data.frame". If \code{x} is a "data.frame" each variable (column) must be an \code{integer} or a \code{factor}. If \code{x} is a "matrix" it is assumed that the categories for each variable in \code{x} start with \code{1} -- there is no check for that !!!
-#'  
-#' 
+#' @param x an object of class "matrix" or "data.frame". If \code{x} is a "data.frame" each variable (column) must be an \code{integer} or a \code{factor}. If \code{x} is a "matrix" it is assumed that the categories for each variable in \code{x} start with \code{1} -- there is no check for that !!! 
+#' @param katorder logical with default set to \code{katorder==FALSE}. When set to \code{katorder==TRUE} variables are ordered according to their number of categories (variable with most categories is the rightmost variable) in the resulting object. 
+#' @param caseorder logical with default set to \code{caseorder==TRUE}. When set to \code{caseorder==FALSE} configurations are only ordered according to the categories of the rightmost variable in the resulting object.
 #' @param kat ignored when \code{x} is a \code{data.frame}! If \code{x} is a \code{"matrix"} the optional argument \code{kat} must be an integer vector defining the number of categories for every variable in \code{x} (in the respective order). If left empty the (max) number of categories ist estimated from the data given in \code{x}.
 #' @param codes a list with character vectors containing coding for integers in matrix (if \code{x} is a numeric \code{matrix}). If \code{codes} is not empty (and the argument \code{x} is an object of class "matrix") the return object will be pattern frequencies table as \code{data.frame}.   
-#' @return An object of class c("data.frame","Pfreq") containing the (response) pattern frequencies table representation of the  given dataset in the argument \code{x}. 
+#' @return An object of class c("data.frame","Pfreq") containing the (response) pattern frequencies table representation of the given dataset in the argument \code{x}. 
 #' @references No references in the moment 
 #' @examples #######################################
 #' data(suicide)# loading data in data frame (702 cases) representation 
@@ -29,22 +29,22 @@
 ############### start of function definition ##################
 ###########  data to pattern frequency conversion #############
 ################ jhheine at googlemail.com ####################
-dat2fre <- function(x,kat=NULL,codes=NULL) {
+dat2fre <- function(x, katorder=FALSE, caseorder=TRUE, kat=NULL, codes=NULL) {
   #### wenn x ein data.frame ist ... 
   #### funktioniert bei: nur factors, nur integers, und gemischt
   if(class(x)=="data.frame"){
     unorderedresult<-as.data.frame(table(x))# ungeordnetes tabulationsergebnis 
     
-    ### sortieren der variablen nach deren kategoriezahl  
+  if(katorder==TRUE){### sortieren der variablen nach deren kategoriezahl  
     variablesorter<-order(sapply(  sapply(unorderedresult[,1:dim(unorderedresult)[2]-1],table,simplify=F)   ,length))
     # variablesorter<-order(sapply(apply(unorderedresult[,1:dim(unorderedresult)[2]-1],2,table),length))
-    varorderedresult<-unorderedresult[,c(variablesorter,dim(unorderedresult)[2])]
+    varorderedresult<-unorderedresult[,c(variablesorter,dim(unorderedresult)[2])]} else{varorderedresult<-unorderedresult} 
     
-    ### sortieren der 'fälle' bzw konfigurationen nach variablen kategorien aufsteigend
+   if(caseorder==TRUE){ ### sortieren der 'fälle' bzw konfigurationen nach variablen kategorien aufsteigend
     calllist<-lapply(varorderedresult,rank)
     do.call("order", calllist)
     result <- varorderedresult[do.call("order", calllist), ] 
-    rownames(result)<-1:dim(result)[1]
+    rownames(result)<-1:dim(result)[1] } else{result <- varorderedresult }
     
     cat("Number of categories for each variable","\n","estimated from data are: " , "\n",sapply(lapply((result[,1:(dim(result)[2]-1)]),levels),length) ,"\n", "-->",dim(result)[1],"different configurations","\n")
     
